@@ -145,7 +145,7 @@ our @EXPORT_OK = qw{
 our %EXPORT_TAGS = (
     ALL => [@EXPORT_OK],
 );
-our $VERSION = '1.112';
+our $VERSION = '1.114';
 
 #####################################################################
 # Interface Functions
@@ -460,7 +460,7 @@ sub _search_inc_path
         sub {
             my $d;
             $d = File::Spec->catdir($_, $path) if defined _STRING($_);
-            defined $d and -d $d and return $d;
+            defined $d and -d $d ? $d : 0;
         },
         @INC
     ) or return;
